pub struct App {
pub cluster: String,
pub config: InternalConfig,
pub search_query: ValidSearchQuery,
}Expand description
Struct exposing different functions for consuming kafka records.
Fields
cluster: Stringconfig: InternalConfigsearch_query: ValidSearchQueryImplementations
Sourceimpl App
impl App
pub fn new( cluster: String, config: InternalConfig, search_query: ValidSearchQuery, ) -> Self
pub fn schema_registry(&self) -> Option<SchemaRegistryClient>
Sourcepub fn create_consumer(
&self,
topics: &Vec<String>,
) -> Result<StreamConsumer, Error>
pub fn create_consumer( &self, topics: &Vec<String>, ) -> Result<StreamConsumer, Error>
Create a kafka consumer
pub fn consumer_config(&self) -> ConsumerConfig
Sourcepub fn export_record(&self, record: &KafkaRecord) -> Result<(), Error>
pub fn export_record(&self, record: &KafkaRecord) -> Result<(), Error>
Exports a given kafka record to a file. The Name of the file is automatically generated at the runtime
Sourcepub fn estimate_number_of_records_to_read(
&self,
topic_partition_list: &TopicPartitionList,
) -> Result<i64, Error>
pub fn estimate_number_of_records_to_read( &self, topic_partition_list: &TopicPartitionList, ) -> Result<i64, Error>
Calculates an estimate of the number of records that are going to be read. This function is used to render a progress bar.
Sourcepub fn topic_details(
&self,
topics: HashSet<String>,
) -> Result<Vec<TopicDetail>, Error>
pub fn topic_details( &self, topics: HashSet<String>, ) -> Result<Vec<TopicDetail>, Error>
Returns the topics details for a given list topics This function is not ready yet
pub async fn topic_config_of( &self, topic: &str, ) -> Result<Option<TopicConfig>, Error>
pub fn count_records_in_topic(&self, topic: &str) -> Result<i64, Error>
Sourcepub fn list_topics(&self) -> Result<Vec<String>, Error>
pub fn list_topics(&self) -> Result<Vec<String>, Error>
Lists available kafka topics on the cluster.
Sourcepub fn list_topics_from_client(
yozefu_config: &YozefuConfig,
) -> Result<Vec<String>, Error>
pub fn list_topics_from_client( yozefu_config: &YozefuConfig, ) -> Result<Vec<String>, Error>
Lists available topics on the cluster with a custom kafka client.